@@ -1,5 +1,7 @@
 """CL device arrays."""
 
+# pylint:disable=unexpected-keyword-arg  # for @elwise_kernel_runner
+
 from __future__ import division, absolute_import
 
 __copyright__ = "Copyright (C) 2009 Andreas Kloeckner"
@@ -425,13 +427,13 @@ class Array(object):
 
         # invariant here: allocator, queue set
 
-        # {{{ determine shape and strides
+        # {{{ determine shape, size, and strides
         dtype = np.dtype(dtype)
 
         try:
-            s = 1
+            size = 1
             for dim in shape:
-                s *= dim
+                size *= dim
         except TypeError:
             import sys
             if sys.version_info >= (3,):
@@ -442,12 +444,11 @@ class Array(object):
             if not isinstance(shape, admissible_types):
                 raise TypeError("shape must either be iterable or "
                         "castable to an integer")
-            s = shape
+            size = shape
             shape = (shape,)
 
-        if isinstance(s, np.integer):
-            # bombs if s is a Python integer
-            s = np.asscalar(s)
+        if isinstance(size, np.integer):
+            size = size.item()
 
         if strides is None:
             strides = _make_strides(dtype.itemsize, shape, order)
@@ -475,7 +476,7 @@ class Array(object):
         else:
             self.events = events
 
-        self.size = s
+        self.size = size
         alloc_nbytes = self.nbytes = self.dtype.itemsize * self.size
 
         self.allocator = allocator
@@ -2001,15 +2002,16 @@ def _arange_knl(result, start, step):
 
 
 def arange(queue, *args, **kwargs):
-    """Create a :class:`Array` filled with numbers spaced `step` apart,
-    starting from `start` and ending at `stop`.
+    """arange(queue, [start, ] stop [, step], **kwargs)
+    Create a :class:`Array` filled with numbers spaced `step` apart,
+    starting from `start` and ending at `stop`. If not given, *start*
+    defaults to 0, *step* defaults to 1.
 
     For floating point arguments, the length of the result is
     `ceil((stop - start)/step)`.  This rule may result in the last
     element of the result being greater than `stop`.
 
-    *dtype*, if not specified, is taken as the largest common type
-    of *start*, *stop* and *step*.
+    *dtype* is a required keyword argument.
 
     .. versionchanged:: 2011.1
         *context* argument was deprecated.
@@ -2280,9 +2282,8 @@ def multi_put(arrays, dest_indices, dest_shape=None, out=None, queue=None,
     vec_count = len(arrays)
 
     if out is None:
-        out = [Array(queue, dest_shape, a_dtype,
-            allocator=a_allocator, queue=queue)
-            for i in range(vec_count)]
+        out = [Array(queue, dest_shape, a_dtype, allocator=a_allocator)
+                for _ in range(vec_count)]
     else:
         if a_dtype != single_valued(o.dtype for o in out):
             raise TypeError("arrays and out must have the same dtype")
