@@ -106,6 +106,11 @@ class CacheLockManager(CleanupBase):
                     warn("could not obtain cache lock--delete '%s' if necessary"
                             % self.lock_file)
 
+                if attempts > 3 * 60:
+                    raise RuntimeError("waited more than three minutes "
+                            "on the lock file '%s'"
+                            "--something is wrong" % self.lock_file)
+
             cleanup_m.register(self)
 
     def clean_up(self):
@@ -480,10 +485,9 @@ def create_built_program_from_source_cached(ctx, src, options_bytes, devices=Non
             already_built = False
 
     except Exception as e:
-        raise
         from pyopencl import Error
         if (isinstance(e, Error)
-                and e.code == _cl.status_code.BUILD_PROGRAM_FAILURE):
+                and e.code == _cl.status_code.BUILD_PROGRAM_FAILURE):  # noqa pylint:disable=no-member
             # no need to try again
             raise
 
